==> web2sms_0.1.2-7.tar.gz: web2sms-0.1.2/src/providers/webtexter/translations/webtexter_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>WebTexterAccountSettingsDialog</name>
    <message>
        <location filename="../webtexteraccountsettingsdialog.ui" line="14"/>
        <source>WebTexter Account</source>
        <translation>WebTexter Konto</translation>
    </message>
    <message>
        <location filename="../webtexteraccountsettingsdialog.ui" line="22"/>
        <source>Username:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <location filename="../webtexteraccountsettingsdialog.ui" line="32"/>
        <source>Password:</source>
        <translation>Kennwort:</translation>
    </message>
    <message>
        <location filename="../webtexteraccountsettingsdialog.ui" line="46"/>
        <source>Use proxy script</source>
        <translation>Proxy Script verwenden</translation>
    </message>
    <message>
        <location filename="../webtexteraccountsettingsdialog.ui" line="53"/>
        <source>Proxy URL:</source>
        <translation>Proxy URL:</translation>
    </message>
</context>
<context>
    <name>WebTexterProvider</name>
    <message>
        <location filename="../webtexter.cpp" line="166"/>
        <source>Error logging in!</source>
        <translation>Fehler beim Anmelden!</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="170"/>
        <source>Unable to send message!</source>
        <translation>Kann Nachricht nicht senden!</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="174"/>
        <source>Unknown error happened!</source>
        <translation>Unbekannter Fehler!</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="184"/>
        <source>Standard</source>
        <translation>Standard</translation>
    </message>
</context>
<context>
    <name>WebTexterProviderPlugin</name>
    <message>
        <location filename="../webtexter.cpp" line="205"/>
        <source>Vodafone Ireland</source>
        <translation>Vodafone Irland</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="206"/>
        <source>o2 Ireland</source>
        <translation>o2 Irland</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="207"/>
        <source>3 Ireland</source>
        <translation>3 Irland</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="208"/>
        <source>Meteor Ireland</source>
        <translation>Meteor Irland</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="209"/>
        <source>Blueface Ireland</source>
        <translation>Blueface Irland</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="210"/>
        <source>VoipCheap.com</source>
        <translation>VoipCheap.com</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="211"/>
        <source>SMSdiscount.com</source>
        <translation>SMSdiscount.com</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="212"/>
        <source>Lowratevoip.com</source>
        <translation>lowratevoip.com</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="213"/>
        <source>Other Betamax</source>
        <translation>Anderer Betamax</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="214"/>
        <source>WebSMS.ru</source>
        <translation>WebSMS.ru</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="215"/>
        <source>Exetel Australia</source>
        <translation>Exetel Australien</translation>
    </message>
</context>
</TS>

==> web2sms_0.1.2-9.tar.gz: web2sms-0.1.2/src/providers/webtexter/translations/webtexter_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>WebTexterAccountSettingsDialog</name>
    <message>
        <location filename="../webtexteraccountsettingsdialog.ui" line="14"/>
        <source>WebTexter Account</source>
        <translation>WebTexter Konto</translation>
    </message>
    <message>
        <location filename="../webtexteraccountsettingsdialog.ui" line="22"/>
        <source>Username:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <location filename="../webtexteraccountsettingsdialog.ui" line="32"/>
        <source>Password:</source>
        <translation>Kennwort:</translation>
    </message>
    <message>
        <location filename="../webtexteraccountsettingsdialog.ui" line="46"/>
        <source>Use proxy script</source>
        <translation>Proxy Script verwenden</translation>
    </message>
    <message>
        <location filename="../webtexteraccountsettingsdialog.ui" line="53"/>
        <source>Proxy URL:</source>
        <translation>Proxy URL:</translation>
    </message>
    <message>
        <location filename="../webtexteraccountsettingsdialog.ui" line="63"/>
        <source>Phone number:</source>
        <translation>Telefonnummer:</translation>
    </message>
</context>
<context>
    <name>WebTexterProvider</name>
    <message>
        <location filename="../webtexter.cpp" line="165"/>
        <source>Error logging in!</source>
        <translation>Fehler beim Anmelden!</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="169"/>
        <source>Unable to send message!</source>
        <translation>Kann Nachricht nicht senden!</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="176"/>
        <source>Unknown error happened!</source>
        <translation>Unbekannter Fehler!</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="186"/>
        <source>Standard</source>
        <translation>Standard</translation>
    </message>
</context>
<context>
    <name>WebTexterProviderPlugin</name>
    <message>
        <location filename="../webtexter.cpp" line="203"/>
        <source>Vodafone Ireland</source>
        <translation>Vodafone Irland</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="204"/>
        <source>o2 Ireland</source>
        <translation>o2 Irland</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="205"/>
        <source>3 Ireland</source>
        <translation>3 Irland</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="206"/>
        <source>Meteor Ireland</source>
        <translation>Meteor Irland</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="207"/>
        <source>Blueface Ireland</source>
        <translation>Blueface Irland</translation>
    </message>
    <message>
        <source>VoipCheap.com</source>
        <translation type="obsolete">VoipCheap.com</translation>
    </message>
    <message>
        <source>SMSdiscount.com</source>
        <translation type="obsolete">SMSdiscount.com</translation>
    </message>
    <message>
        <source>Lowratevoip.com</source>
        <translation type="obsolete">lowratevoip.com</translation>
    </message>
    <message>
        <source>Other Betamax</source>
        <translation type="obsolete">Anderer Betamax</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="208"/>
        <source>WebSMS.ru</source>
        <translation>WebSMS.ru</translation>
    </message>
    <message>
        <location filename="../webtexter.cpp" line="209"/>
        <source>Exetel Australia</source>
        <translation>Exetel Australien</translation>
    </message>
</context>
</TS>
